==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridRowEditTextTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditTextTemplateContextDescription } from "./WebGridRowEditTextTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridRowEditTextTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridRowEditTextTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridRowEditTextTemplateContextDescriptionMetadata.a == null) {
                WebGridRowEditTextTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridRowEditTextTemplateContextDescriptionMetadata.c(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridRowEditTextTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridRowEditTextTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "Number:double");
        }
        static d(a) {
            WebGridRowEditTextTemplateContextDescriptionMetadata.b(a);
            a.ad("WebGridRowEditTextTemplateContext", () => new WebGridRowEditTextTemplateContextDescription());
            a.ac("WebGridRowEditTextTemplateContext", WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridRowEditTextTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditTextTemplateContextDescriptionMetadata, 'WebGridRowEditTextTemplateContextDescriptionMetadata');
    WebGridRowEditTextTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditTextTemplateContextDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridRowEditTextTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditTextTemplateContextDescription } from "./WebGridRowEditTextTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridRowEditTextTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridRowEditTextTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridRowEditTextTemplateContextDescriptionMetadata.a == null) {
                WebGridRowEditTextTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridRowEditTextTemplateContextDescriptionMetadata.c(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridRowEditTextTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridRowEditTextTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "Number:double");
        }
        static d(a) {
            WebGridRowEditTextTemplateContextDescriptionMetadata.b(a);
            a.ae("WebGridRowEditTextTemplateContext", () => new WebGridRowEditTextTemplateContextDescription());
            a.ad("WebGridRowEditTextTemplateContext", WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridRowEditTextTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditTextTemplateContextDescriptionMetadata, 'WebGridRowEditTextTemplateContextDescriptionMetadata');
    WebGridRowEditTextTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditTextTemplateContextDescriptionMetadata;
})();
